dot-replace.methods.with.spy: Replace methods in global namespace with the spying methods...

.replace.methods.with.spyR Documentation

Replace methods in global namespace with the spying methods defined below

Description

Replace methods in global namespace with the spying methods defined below

Usage

.replace.methods.with.spy(methods)

ihmeuw/ihme.covid documentation built on Nov. 2, 2022, 2:25 a.m.