get_latest_output_date_index: get the latest index for given an output dir and a date

View source: R/get_latest_output_date_index.R

get_latest_output_date_indexR Documentation

get the latest index for given an output dir and a date

Description

directories are assumed to be named in YYYY_MM_DD.VV format with sane year/month/date/version values.

Usage

get_latest_output_date_index(dir, date)

Arguments

dir

path to directory with versioned dirs

date

character in be YYYY_MM_DD format

Value

largest version in directory tree or 0 if there are no version OR the directory tree does not exist


ihmeuw/ihme.covid documentation built on Nov. 2, 2022, 2:25 a.m.